pub struct ScrollableContent {
pub pos_y: f32,
pub max_scroll: f32,
}Expand description
Component containing offset value of the scroll container to the parent.
It is possible to update the field pos_y manually to move scrollview to desired location.
Fields
pos_y: f32Scroll container offset to the ScrollView.
max_scroll: f32Maximum value for the scroll. It is updated automatically based on the size of the children nodes.
Implementations
Sourceimpl ScrollableContent
impl ScrollableContent
Sourcepub fn scroll_to_top(&mut self)
pub fn scroll_to_top(&mut self)
Scrolls to the top of the scroll view.
Sourcepub fn scroll_to_bottom(&mut self)
pub fn scroll_to_bottom(&mut self)
Scrolls to the bottom of the scroll view.